@@ -82,115 +82,119 @@ ss.ci<-function(x, sigma2 = NA, alpha = 0.05, data = NA,
     .ss.prepCanvas(main,sub, ss.col)
 
 ##figures
-    vp.figures <- viewport(name = "figures", 
+    vp.figures <- grid::viewport(name = "figures", 
 			x = 0, 
 			width = 1, 
 			height = unit(8, "lines"),
 			y = 1, 
 			just = c("left", "top"),
-			layout = grid.layout(1, 2, widths = c(0.4, 0.6))						 )
-    pushViewport(vp.figures)
+			layout = grid::grid.layout(1, 2, widths = c(0.4, 0.6))						 )
+    grid::pushViewport(vp.figures)
 
-    vp.figures1 <- viewport(name = "figures1", 
+    vp.figures1 <- grid::viewport(name = "figures1", 
 			layout.pos.col = 1, 
 			layout.pos.row = 1)
-    pushViewport(vp.figures1)
-    grid.roundrect(height = unit(7, "lines"), 
+    grid::pushViewport(vp.figures1)
+    grid:: grid.roundrect(height = unit(7, "lines"), 
        width = 0.95,
-       gp = gpar(fill = ss.col[5], col = ss.col[2], lwd=2))
-    grid.text("Mean:\nStdDev:\nn:\nMissing:", just = "left",
+       gp = grid::gpar(fill = ss.col[5], col = ss.col[2], lwd=2))
+    grid:: grid.text("Mean:\nStdDev:\nn:\nMissing:", just = "left",
 		x = unit(1, "npc") - unit(5.5, "cm"), 
-		gp = gpar(fontface = c("bold")))
-    grid.text(paste(round(m, digits), "\n", round(s, digits), "\n", n,
+		gp = grid::gpar(fontface = c("bold")))
+    grid:: grid.text(paste(round(m, digits), "\n", round(s, digits), "\n", n,
 					"\n", na, sep = ""), just = "right", 
 			x = unit(1, "npc") - unit(1, "cm"))
 
 
-    popViewport()
-    vp.figures2 <- viewport(name = "figures2", layout.pos.col = 2,
+    grid::popViewport()
+    vp.figures2 <- grid::viewport(name = "figures2", layout.pos.col = 2,
 			layout.pos.row = 1)
-    pushViewport(vp.figures2)
-    grid.roundrect(height = unit(7, "lines"), 
+    grid::pushViewport(vp.figures2)
+    grid:: grid.roundrect(height = unit(7, "lines"), 
             width = 0.95,
-            gp = gpar(fill = ss.col[5], col = ss.col[2], lwd = 2))
+            gp = grid::gpar(fill = ss.col[5], col = ss.col[2], lwd = 2))
 
-    grid.text(paste((1-alpha)*100, "% CI:\nP-Var:\n",
+    grid:: grid.text(paste((1-alpha)*100, "% CI:\nP-Var:\n",
                     st.dist, ":", sep = ""),
               just = "left",
               x = unit(0,"npc") + unit(1,"cm"), 
-			  gp = gpar(fontface=c("bold")))
-    grid.text(paste("[", round(ci[1], digits), ", ", round(ci[2], digits),
+			  gp = grid::gpar(fontface=c("bold")))
+    grid:: grid.text(paste("[", round(ci[1], digits), ", ", round(ci[2], digits),
             "]\n", ifelse(is.numeric(sigma2), sigma2, "unknown"),
 			"\n", round(st, digits),
             sep = ""), just = "right", 
 			x = unit(0,"npc") + unit(7.5,"cm"))
-    popViewport()
-    popViewport()
+    grid::popViewport()
+    grid::popViewport()
 
 #graph
-    vp.graph <- viewport(name = "graph", 
+    vp.graph <- grid::viewport(name = "graph", 
 			y = 0, 
 			width = 0.95,
             height = unit(1, "npc") - unit(8, "lines"),
             just = c("center", "bottom"),
-			layout = grid.layout(1, 2, 
+			layout = grid::grid.layout(1, 2, 
 				widths = unit(c(1, 6), c("null", "cm"))))
-    pushViewport(vp.graph)
+    grid::pushViewport(vp.graph)
 	
-    vp.test <- viewport(name = "test", layout.pos.row = 1, layout.pos.col = 2)
-    pushViewport(vp.test)
-    grid.rect()
-    grid.roundrect(height = unit(6, "lines"),
+    vp.test <- grid::viewport(name = "test", layout.pos.row = 1, layout.pos.col = 2)
+    grid::pushViewport(vp.test)
+    grid::grid.rect()
+    grid:: grid.roundrect(height = unit(6, "lines"),
                    width = 0.9, 
 				   y = unit(1, "npc") + unit(-1, "lines"),
 				   just = "top",
-                   gp = gpar(fill = ss.col[5], col = ss.col[2], lwd = 2))
+                   gp = grid::gpar(fill = ss.col[5], col = ss.col[2], lwd = 2))
 
-    grid.text("Shapiro-Wilks\nNormality Test\n", 
+    grid:: grid.text("Shapiro-Wilks\nNormality Test\n", 
 			y = unit(1, "npc") - unit(3, "lines"),
-			gp = gpar(fontface = c("bold")))
+			gp = grid::gpar(fontface = c("bold")))
 	pval <- shapiro.test(x)[2]$p.value 
 	if (pval < 0.05){
 		warning("Sample data is non-normal.")
 	}
-    grid.text(paste(round(shapiro.test(x)[1]$statistic, digits), "\n"),
+    grid:: grid.text(paste(round(shapiro.test(x)[1]$statistic, digits), "\n"),
 			y = unit(1, "npc") - unit(5, "lines"))
-    grid.text(paste("p-value:", round(pval, digits), "\n"),
+    grid:: grid.text(paste("p-value:", round(pval, digits), "\n"),
               y = unit(1, "npc") - unit(6, "lines"))
 	
-	vp.qq <- viewport(name="qqp", 
+	vp.qq <- grid::viewport(name="qqp", 
 			x = 0.5, y=0.25,
 			  height = unit(0.6,"npc"))
-	pushViewport(vp.qq)
-	qqp <- qplot(sample = x, stat="qq") + 
+	grid::pushViewport(vp.qq)
+	qqp <- qplot(sample = x
+	             # , stat="qq"
+	             ) + 
 			  xlab(NULL) + ylab(NULL) +
 			  theme(axis.text.x = element_blank(),
 					  axis.text.y = element_blank()) +
                     ggtitle("Normal q-q Plot")
               
 	print(qqp,newpage=FALSE)  
-	popViewport()
-    popViewport()
+	grid::popViewport()
+    grid::popViewport()
 
-    vp.hist <- viewport(name = "hist", 
+    vp.hist <- grid::viewport(name = "hist", 
 			layout.pos.row = 1,
 			layout.pos.col = 1)
-    pushViewport(vp.hist)
-    grid.rect()
+    grid::pushViewport(vp.hist)
+    grid::grid.rect()
 	
 	ggdata <- reshape2::melt(x)
 	binw <- diff(range(x))/ sqrt(n)
 	qqp <- ggplot(ggdata, aes(x = value))
 	myhist <- qqp + 
 			geom_histogram(aes(y = ..density..), 
-					binwidth = binw,
+					# binwidth = binw,
 					fill = "white",
-					col = "gray",
-					stat = "bin") +
+					col = "gray"
+					# , stat = "bin"
+					) +
 			xlab(paste("Value of", deparse(substitute(x)))) +
 			ggtitle("Histogram & Density Plot") +
-			stat_density(geom="path", position="identity", 
-					binwidth = binw,
+			stat_density(geom = "path", 
+			             position = "identity", 
+					# binwidth = binw,
 					size = 1) 
     suppressWarnings(
       print(myhist, newpage=FALSE)
